---
name: Bug report
about: Create a report to help us improve
title: "[Bug]: "
labels: bug
assignees: kenblu24

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Environment & Version Info (please complete the following information):**
 - OS (i.e. Windows 10 x64, MacOS, Linux Distro...): 
 - Python Version : 
 - SuperNeuroMAT Version :

**Additional context**
Add any other context about the problem here.
